@@ -151,6 +151,9 @@ export TMUX_LOG="$MODEL_LOG"
 export PROJECT_NAME="$PROJECT_NAME"
 export LOG_DIR="$LOG_DIR"
 export ROOT_DIR="$SOURCE_ROOT"
+if [[ -n "${CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING:-}" ]]; then
+  export CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING
+fi
 
 "$SOURCE_ROOT/scripts/start_tmux_codex.sh" --kill >/dev/null
 
