@@ -186,21 +186,105 @@ check_deps_installed() {
   return 0
 }
 
-if pgrep -f "python.*master.py" >/dev/null 2>&1; then
-  log_info "检测到历史 master 实例，正在终止..."
-  pkill -f "python.*master.py" || true
-  sleep 1
-  if pgrep -f "python.*master.py" >/dev/null 2>&1; then
-    log_info "残留 master 进程仍在，执行强制结束"
-    pkill -9 -f "python.*master.py" || true
-    sleep 1
+# 清理旧 master 进程的健壮函数（改进版：支持 PID 文件 + pgrep 双保险）
+cleanup_old_master() {
+  local max_wait=10  # 最多等待10秒优雅退出
+  local waited=0
+  local old_pids=""
+  local master_pid_file="${MASTER_CONFIG_ROOT:-$HOME/.config/vibego}/state/master.pid"
+
+  # 方案1：优先从 PID 文件读取
+  if [[ -f "$master_pid_file" ]]; then
+    local pid_from_file
+    pid_from_file=$(cat "$master_pid_file" 2>/dev/null || true)
+    if [[ "$pid_from_file" =~ ^[0-9]+$ ]]; then
+      if kill -0 "$pid_from_file" 2>/dev/null; then
+        old_pids="$pid_from_file"
+        log_info "从 PID 文件检测到旧 master 实例（PID: $old_pids）"
+      else
+        log_info "PID 文件存在但进程已不在，清理过期 PID 文件"
+        rm -f "$master_pid_file"
+      fi
+    fi
   fi
-  if pgrep -f "python.*master.py" >/dev/null 2>&1; then
-    log_error "仍存在 master 进程，请手动检查后再启动"
+
+  # 方案2：使用 pgrep 查找（支持多种运行方式）
+  if [[ -z "$old_pids" ]]; then
+    # 匹配模式：支持源码运行和 pipx 安装的方式
+    # - python.*master.py（源码运行）
+    # - Python.*master.py（macOS 上的 Python.app）
+    # - bot.py（pipx 安装的 master 别名）
+    local pgrep_pids
+    pgrep_pids=$(pgrep -f "master\.py$" 2>/dev/null || true)
+    if [[ -n "$pgrep_pids" ]]; then
+      old_pids="$pgrep_pids"
+      log_info "通过 pgrep 检测到旧 master 实例（PID: $old_pids）"
+    fi
+  fi
+
+  # 如果两种方式都没找到，说明没有旧进程
+  if [[ -z "$old_pids" ]]; then
+    log_info "未检测到旧 master 实例"
+    return 0
+  fi
+
+  # 开始清理旧进程
+  log_info "正在优雅终止旧 master 实例（PID: $old_pids）..."
+
+  # 发送 SIGTERM 信号优雅终止
+  for pid in $old_pids; do
+    kill -15 "$pid" 2>/dev/null || true
+  done
+
+  # 循环等待进程退出
+  while (( waited < max_wait )); do
+    sleep 1
+    ((waited++))
+
+    # 检查所有 PID 是否都已退出
+    local all_exited=1
+    for pid in $old_pids; do
+      if kill -0 "$pid" 2>/dev/null; then
+        all_exited=0
+        break
+      fi
+    done
+
+    if (( all_exited )); then
+      log_info "✅ 旧 master 已优雅退出（耗时 ${waited}秒）"
+      rm -f "$master_pid_file"
+      return 0
+    fi
+  done
+
+  # 优雅终止超时，执行强制结束
+  log_info "优雅终止超时（${max_wait}秒），执行强制结束..."
+  for pid in $old_pids; do
+    kill -9 "$pid" 2>/dev/null || true
+  done
+  sleep 2
+
+  # 最后检查
+  local remaining_pids=""
+  for pid in $old_pids; do
+    if kill -0 "$pid" 2>/dev/null; then
+      remaining_pids="$remaining_pids $pid"
+    fi
+  done
+
+  if [[ -n "$remaining_pids" ]]; then
+    log_error "❌ 无法清理旧 master 进程（残留 PID:$remaining_pids）"
+    log_error "请手动执行: kill -9$remaining_pids"
     exit 1
   fi
-  log_info "历史 master 实例已清理"
-fi
+
+  log_info "✅ 旧 master 实例已强制清理"
+  rm -f "$master_pid_file"
+  return 0
+}
+
+# 调用清理函数
+cleanup_old_master
 
 # 智能依赖管理：仅在必要时安装
 REQUIREMENTS_FILE="${VIBEGO_REQUIREMENTS_PATH:-$ROOT_DIR/scripts/requirements.txt}"
@@ -256,7 +340,34 @@ if [[ -n "${MASTER_RESTART_EXPECTED:-}" ]]; then
 fi
 
 log_info "准备启动 master 进程..."
-nohup python master.py >> /dev/null 2>&1 &
+
+# 清理旧的错误日志（保留最近 10 次）
+cleanup_old_error_logs() {
+  local error_log_pattern="$LOG_DIR/master_error_*.log"
+  local error_logs
+  error_logs=$(ls -t $error_log_pattern 2>/dev/null || true)
+  if [[ -n "$error_logs" ]]; then
+    local count=0
+    while IFS= read -r logfile; do
+      ((count++))
+      if (( count > 10 )); then
+        rm -f "$logfile"
+        log_info "已清理旧错误日志: $logfile"
+      fi
+    done <<< "$error_logs"
+  fi
+}
+
+cleanup_old_error_logs
+
+# 创建带时间戳的错误日志文件
+MASTER_ERROR_LOG="$LOG_DIR/master_error_$(date +%Y%m%d_%H%M%S).log"
+MASTER_STDOUT_LOG="$LOG_DIR/master_stdout.log"
+
+# 显式传递环境变量给 nohup 进程，确保重启信号文件路径正确
+# 使用虚拟环境的 Python 解释器，避免版本不匹配导致依赖加载失败
+# 重要：将 stderr 保存到日志文件，方便排查启动失败问题
+MASTER_RESTART_SIGNAL_PATH="$MASTER_RESTART_SIGNAL_PATH" nohup "$ROOT_DIR/.venv/bin/python" master.py > "$MASTER_STDOUT_LOG" 2> "$MASTER_ERROR_LOG" &
 MASTER_PID=$!
 
 # 健壮性检查：确保进程成功启动
@@ -273,7 +384,20 @@ if ! kill -0 "$MASTER_PID" 2>/dev/null; then
   log_error "请检查："
   log_error "  - master.py 是否有语法错误: python master.py"
   log_error "  - 依赖是否完整: pip list | grep aiogram"
-  log_error "  - 最近的错误日志: tail -50 $ROOT_DIR/vibe.log"
+  log_error "  - 错误日志: $MASTER_ERROR_LOG"
+
+  # 输出错误日志的最后 20 行，帮助快速定位问题
+  if [[ -s "$MASTER_ERROR_LOG" ]]; then
+    log_error ""
+    log_error "=== 错误日志最后 20 行 ==="
+    tail -20 "$MASTER_ERROR_LOG" | while IFS= read -r line; do
+      log_error "  $line"
+    done
+    log_error "=========================="
+  else
+    log_error "错误日志文件为空，可能是环境变量或路径问题"
+  fi
+
   exit 1
 fi
 
